﻿using System;
using System.Collections.Generic;
using EleWise.ELMA.LdapSample.Settings;
using EleWise.ELMA.Security.Services;
using IUser = EleWise.ELMA.Security.IUser;

namespace EleWise.ELMA.LdapSample.Services
{
    /// <summary>
    /// Интерфейс сервиса работы с LDAP
    /// </summary>
    public interface ILdapService
    {

        #region Синхронизация пользователя

        ///<summary>
        /// Заполнение свойств пользователя данными из LDAP
        ///</summary>
        void Sync(IUser user, LdapExternalMembershipModuleSettings settings);

        #endregion

        #region Валидация

        /// <summary>
        /// Валидация по Distinguished Names
        /// </summary>
        bool ValidatingDN(UserValidationContext context, LdapExternalMembershipModuleSettings settings);

        /// <summary>
        /// Валидация по доменному имени
        /// </summary>
        bool ValidatingTemplate(UserValidationContext context, LdapExternalMembershipModuleSettings settings);

        /// <summary>
        /// Валидация по Distinguished Names
        /// </summary>
        bool ValidatingDN(string userName, string password, LdapExternalMembershipModuleSettings settings);

        /// <summary>
        /// Валидация по доменному имени
        /// </summary>
        bool ValidatingTemplate(string userName, string password, LdapExternalMembershipModuleSettings settings);

        #endregion

        #region Поиск

        /// <summary>
        /// Поиск пользователей в LDAP
        /// </summary>
        IEnumerable<IUser> FindUsers(string searchString, LdapExternalMembershipModuleSettings settings, Guid serviceUid);

        #endregion

    }
}
